@@ -205,10 +205,23 @@ def write_log(file_name, text, is_new = False):
     
 def read_file(file_name, return_type='str'):
   if return_type == 'str' :
-    return codecs.open(file_name, 'r', 'utf8').read()
+    #return codecs.open(file_name, 'r', 'utf8').read() -- codecs.open obsolete
+    return open(file_name, 'r', encoding='utf-8').read()
+    
     
   if return_type == 'list' :
-    return codecs.open(file_name, 'r', 'utf8' ).readlines() 
+    #return codecs.open(file_name, 'r', 'utf8' ).readlines() -- codecs.open obsolete
+    return open(file_name, 'r', encoding='utf-8').readlines()
+
+
+def read_file_lines(file_object, chunk_size=1024):
+    #Lazy function (generator) to read a huge file line by line.
+    while True:
+      line = file_object.readline()
+      if not line:
+        break
+      yield line
+
 
 
 ####################################################################################################
@@ -717,13 +730,25 @@ if __name__ == "__main__":
   
   """
   print (compare_files ( 'R:/TempVM/download/866c6e0a2795e52fc8c99211736a4f70.part_00001', 'R:/TempVM/upload/866c6e0a2795e52fc8c99211736a4f70.part_00000'))
-  """
+  
   for f in gen_files(folder="R:/Temp2", recursive=True, ext="", type='all'):
     print (f)
   
   for f in get_files(folder="R:/Temp2", recursive=True, ext="", type='F'):
     print (f)
+  """
+  
+  """
+  lines = read_file('R:/TempVM/dump.offerings.detail.json', 'list')
+  print (len(lines))
+  
+  exit(1)
+  with open('R:/TempVM/dump.offerings.detail.json') as f:
+    for line in read_file_lines(f):
+       print (line)
 
+  """
+   
   
   pass
   
\ No newline at end of file
