@@ -159,9 +159,11 @@ def render(text, align=None, width=None):
   
 def pause(txt=None) :
   press_keys_info = "Confirm and press [%LGREEN_BG|BLACK:[Enter]%] to continue ... or [%LRED_BG|BLACK:[Ctrl-C]%] to exit ...\n\n"
+  continue_info   = "Pressed [%LGREEN_BG|BLACK:[Enter]%] to continue.\n\n"
   if txt is None : txt = "\n\n---> " 
   pause_txt = txt + press_keys_info
   input(render(pause_txt))
+  print(render(continue_info))
 
 
 def keep_print(text):
